function xb = incsearch(func,xmin,xmax,ns)
// incsearch: Localizador de raices por búsqueda incremental
//   xb = incsearch(func,xmin,xmax,ns):
//      Encuentra intervalos de variación de la variable independiente x 
//      cuyos extremos presentan cambios de signo de una función real 
//      definida sobre un cierto dominio
// Entradas:
//   func = Nombre de la función
//   xmin, xmax = Extremos del intervalo
//   ns = Número de subintervalos (default = 50)
// Salidas:
//   xb(k,1) Es el extremo inferior correspondiente al k-ésimo intervalo 
//   que presenta cambio de signo
//   xb(k,2) Es el extremo superior correspondiente al k-ésimo intervalo 
//   que presenta cambio de signo
//   Si no se encuentran intervalos, xb = [].
[lhs, rhs] = argn()
lhs = argn(1);
rhs = argn(2);
if rhs < 4, ns = 50; end //Si no se ingresa ns, se lo fija en el valor 50
// Búsqueda incremental
x = linspace(xmin,xmax,ns); 
f = func(x);
plot(x,f);
set(gca(),'grid',[1 1])
nb=0; xb=[]; //xb es nulo a menos que se detecte un cambio de signo
for k = 1:length(x)-1
  if sign(f(k))~= sign(f(k+1)) //Verifica si se produce un cambio de signo
    nb=nb+1;
    xb(nb,1)=x(k);
    xb(nb,2)=x(k+1);
  end
end
if isempty(xb)    //Informa que no se encontraron intervalos donde la función cambia de signo
  disp('No se encontraron intervalos')
  disp('Verificar el intervalo de búsqueda o incrementar ns')
else
  disp('Número de subintervalos:') //Muestra el número de subintervalos
  disp(nb)
end
endfunction
